summaryrefslogtreecommitdiffstats
path: root/chrome/browser/cocoa/content_exceptions_window_controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/cocoa/content_exceptions_window_controller.h')
-rw-r--r--chrome/browser/cocoa/content_exceptions_window_controller.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/cocoa/content_exceptions_window_controller.h b/chrome/browser/cocoa/content_exceptions_window_controller.h
index 131cf72..5c012f3 100644
--- a/chrome/browser/cocoa/content_exceptions_window_controller.h
+++ b/chrome/browser/cocoa/content_exceptions_window_controller.h
@@ -31,8 +31,8 @@ class UpdatingContentSettingsObserver;
HostContentSettingsMap* otrSettingsMap_; // weak
scoped_ptr<ContentExceptionsTableModel> model_;
- // Is set if "Ask" should be a valid option in the "action" popup.
- BOOL showAsk_;
+ // Is set if "Session" should be a valid option in the "action" popup.
+ BOOL showSession_;
// Is set if adding and editing exceptions for the current OTR session should
// be allowed.